/*
 * Hanashizume no Matsuri for X
 * Copyright (c) 2000 TF <tf@denpa.org>
 * All rights reserverd.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgment:
 *      This product includes software developed by TF.
 * 4. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * $Id: music.c,v 1.7 2000/08/12 10:32:56 tf Exp $
 */
#include <sys/types.h>
#include <sys/uio.h>
#include <unistd.h>

#include "hana.h"

void music_init()
{
  switch (sys_stat.music_mode) {
  case MUSIC_NONE:
    fprintf(stderr, "Music: None\n");
    sys_stat.music_fd = -1;
    break;
  case MUSIC_CDDA:
    fprintf(stderr, "Music: CD-DA mode\n");
    sys_stat.music_fd = music_cd_process(path.cddevice);
    break;
  case MUSIC_MIDI:
    fprintf(stderr, "Music: MIDI mode\n");
    sys_stat.music_fd = music_midi_process();
    break;
  case MUSIC_MP3:
    fprintf(stderr, "Music: MP3 mode\n");
    sys_stat.music_fd = music_mp3_process();
    break;
  }
}

void music_term()
{
  if (sys_stat.music_fd < 0) {
    return;
  }
  music_stop();
  write(sys_stat.music_fd, "x\n", 2);
  close(sys_stat.music_fd);
  sys_stat.music_fd = -1;
}

void music_play(int track, Bool loop)
{
  char buf[BUFSIZ];

  fprintf(stderr, "play music: %d\n", track);
  scn_stat.track = track;
  if (sys_stat.music_fd < 0) {
    fprintf(stderr, "music: not initialized\n");
    return;
  }

  if (loop) {
    snprintf(buf, BUFSIZ, "l%d\n", track);
  } else {
    snprintf(buf, BUFSIZ, "t%d\n", track);
  }
  write(sys_stat.music_fd, buf, strlen(buf));
}

void music_stop()
{
  scn_stat.track = 0;

  if (sys_stat.music_fd > 0) {
    write(sys_stat.music_fd, "s\n", 2);
  }
}
